==> haskell-lsp-types1.4-1.4.0.1-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.4.0.1
visibility:           public
id:                   lsp-types-1.4.0.1-ATgDhgv4qfFH5C0QOMYDju
key:                  lsp-types-1.4.0.1-ATgDhgv4qfFH5C0QOMYDju
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  4ab1b629d3ee07cda364552cb5471eef
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap
    Language.LSP.VFS

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types1.4
hs-libraries:         HSlsp-types-1.4.0.1-ATgDhgv4qfFH5C0QOMYDju
depends:
    Diff-0.4.1-4VjaazPwKkA8eC2BQCP8tm
    aeson-2.1.2.1-4cRYi3WcVwTKRqMhXUztfB base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-3IsW2ghxYJNLBlqCManDLX filepath-1.4.2.2
    hashable-1.4.4.0-4IkOt4KzeSSA3Xc4u5PLaT
    hslogger-1.3.1.2-HMJk3JrvLkgFTkI0qaqSnU
    lens-5.3-2T63PvFtwZXqnWv0im5sF mod-0.2.0.1-6wiGLGJP6c72nLGdNBHTbi
    mtl-2.2.2 network-uri-2.6.4.2-HPE7I962wSKDZCCiANqdpI
    rope-utf16-splay-0.4.0.0-6Mo5TDwGaChJXen8P8I6lZ
    scientific-0.3.7.0-K2KPplW6Nka7Ws1cS3R2Yx
    some-1.0.6-3zkYDuZM8U6ADWfzDH6sC6 template-haskell-2.19.0.0
    temporary-1.3-9YGAaKVvZD6I8n4DFMUpuQ text-2.0.2
    unordered-containers-0.2.20-A2tjqfQXDXnFd3Ae9FP0C3

haddock-interfaces:   /usr/share/doc/haskell-lsp-types1.4/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types1.4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-types1.4-1.4.0.1-174-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.4.0.1
visibility:           public
id:                   lsp-types-1.4.0.1-EodYKQ0JwMxHYAopbBoYye
key:                  lsp-types-1.4.0.1-EodYKQ0JwMxHYAopbBoYye
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  07249ae964e31e7bb7c3d89051ae262a
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap
    Language.LSP.VFS

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types1.4
hs-libraries:         HSlsp-types-1.4.0.1-EodYKQ0JwMxHYAopbBoYye
depends:
    Diff-0.4.1-CBiY4eyeiRQG8RHG96uHG4
    aeson-2.1.2.1-2ooOAwlErgbHj6Tyvuh2I5 base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-86VyjkfSCk63mGj7Z05i2D deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-3IsW2ghxYJNLBlqCManDLX filepath-1.4.2.2
    hashable-1.4.4.0-CTf4tWLvOCwE4B8hp3PoEK
    hslogger-1.3.1.2-Eg45tkdAwYYLR7iDN6wOZ8
    lens-5.3-AIJaKrXjlD5HhDEbilmzm0 mod-0.2.0.1-F8FGm60PoKwHOzae0K1dlt
    mtl-2.2.2 network-uri-2.6.4.2-G7m9o4Qp8JT5z4xQAeqaNT
    rope-utf16-splay-0.4.0.0-8KCOkKx4los5iaD26NP7G6
    scientific-0.3.7.0-Kb5Gqy0LO2R6GqxRC9SGn9
    some-1.0.6-3LlvMLdrUbW3RBFXcNvNOC template-haskell-2.19.0.0
    temporary-1.3-54wigIt31kD6f0c4NQmX2X text-2.0.2
    unordered-containers-0.2.20-5aRSzj1YCHv4h2N6lFa6Hx

haddock-interfaces:   /usr/share/doc/haskell-lsp-types1.4/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types1.4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
